@@ -1,10 +1,10 @@
 /*******************************************************************
-* reportassistantpage.h
-* SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
-*
-* SPDX-License-Identifier: GPL-2.0-or-later
-*
-******************************************************************/
+ * reportassistantpage.h
+ * SPDX-FileCopyrightText: 2009 Dario Andres Rodriguez <andresbajotierra@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ *
+ ******************************************************************/
 
 #ifndef REPORTASSISTANTPAGE__H
 #define REPORTASSISTANTPAGE__H
@@ -17,17 +17,21 @@ class BugzillaManager;
 
 /** BASE interface which implements some signals, and
 **  aboutTo(Show|Hide) functions (also reimplements QWizard behaviour) **/
-class ReportAssistantPage: public QWidget
+class ReportAssistantPage : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit ReportAssistantPage(ReportAssistantDialog * parent);
+    explicit ReportAssistantPage(ReportAssistantDialog *parent);
 
     /** Load the widget data if empty **/
-    virtual void aboutToShow() {}
+    virtual void aboutToShow()
+    {
+    }
     /** Save the widget data **/
-    virtual void aboutToHide() {}
+    virtual void aboutToHide()
+    {
+    }
     /** Tells the KAssistantDialog to enable the Next button **/
     virtual bool isComplete();
 
@@ -36,17 +40,17 @@ public:
 
     ReportInterface *reportInterface() const;
     BugzillaManager *bugzillaManager() const;
-    ReportAssistantDialog * assistant() const;
+    ReportAssistantDialog *assistant() const;
 
 public Q_SLOTS:
     void emitCompleteChanged();
 
 Q_SIGNALS:
     /** Tells the KAssistantDialog that the isComplete function changed value **/
-    void completeChanged(ReportAssistantPage*, bool);
+    void completeChanged(ReportAssistantPage *, bool);
 
 private:
-    ReportAssistantDialog * const m_assistant;
+    ReportAssistantDialog *const m_assistant;
 };
 
 #endif
